@@ -1,5 +1,5 @@
 from abc import ABC
-from bergen.wards.graphql.base import BaseGraphQLWard
+from bergen.wards.graphql.base import BaseGraphQLWard, GraphQLException
 
 from gql.gql import gql
 from bergen.wards.base import BaseWard
@@ -7,22 +7,29 @@ from bergen.query import GQL, TypedGQL
 from gql.transport.aiohttp import AIOHTTPTransport
 import logging
 from gql.transport.aiohttp import log as aiohttp_logger
+from gql.transport.requests import RequestsHTTPTransport
+
 
 aiohttp_logger.setLevel(logging.WARNING)
 import asyncio
 from gql import Client, gql
+import requests
 
 class AIOHttpGraphQLWard(BaseGraphQLWard):
     can_subscribe = False
 
+    def __init__(self, port, host, protocol, token, loop) -> None:
+        super().__init__(port=port, host=host, protocol=protocol, token=token, loop=loop)
+
     async def configure(self):
         self.transport = AIOHTTPTransport(url=self._graphql_endpoint, headers=self._headers)
-        self.client = Client(transport=self.transport, fetch_schema_from_transport=False)
-        self.session = await self.client.__aenter__()
+        await self.transport.connect()
+
 
     async def run_async(self, the_query: TypedGQL, variables: dict = {}, **kwargs):
         query_node = gql(the_query.query)
 
-        response = await self.session.execute(query_node, variable_values=variables)
-        
-        return the_query.extract(response)
\ No newline at end of file
+        response = await self.transport.execute(query_node, variable_values=variables)
+        if response.errors:
+            raise GraphQLException(str(response.errors))
+        return the_query.extract(response.data)
\ No newline at end of file
